@@ -12,10 +12,9 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Dict, List, Mapping, Sequence, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     ApiCacheStatusType,
@@ -1463,7 +1462,7 @@ StartSchemaCreationRequestRequestTypeDef = TypedDict(
     "StartSchemaCreationRequestRequestTypeDef",
     {
         "apiId": str,
-        "definition": Union[bytes, IO[bytes], StreamingBody],
+        "definition": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 
